# `string.includes(position = 0)` _(ext/string\_/includes)_

`includes` method for strings. Resolve native [includes](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/includes) if implemented, otherwise fallback to shim implementation.

```javascript
const includes = require("ext/string_/includes");

includes.call("razdwa", "raz"); // true
includes.call("razdwa", "trzy"); // false
```
